@@ -3,13 +3,7 @@
 """
 from payton.scene.gui.base import Hud, Rectangle, Shape2D, Text
 from payton.scene.gui.help import info_box
-from payton.scene.gui.window import (
-    Button,
-    Panel,
-    Theme,
-    Window,
-    WindowAlignment,
-)
+from payton.scene.gui.window import Button, Panel, Theme, Window, WindowAlignment
 
 __all__ = [
     "Shape2D",
